Cython: _uint8window.pyx

Generated by Cython 3.1.8

Yellow lines hint at Python interaction.
Click on a line that starts with a "`+`" to see the C code that Cython generated for it.

Raw output: _uint8window.c

    +1: """

      __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_5) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

     2: bool specialization of AdjustedArrayWindow

     3: """

     4: from numpy cimport uint8_t

     5:

    +6: ctypedef uint8_t[:, :] databuffer

    typedef __Pyx_memviewslice __pyx_t_7zipline_3lib_12_uint8window_databuffer;

     7:

     8: include "_windowtemplate.pxi"